/**
 * Simple Profile Picture - Admin JavaScript
 * Handles the media uploader functionality
 * 
 * Copyright (c) 2025 Corenexis
 */
(function($) {
    'use strict';
    
    // When DOM is ready
    $(document).ready(function() {
        var mediaUploader;
        
        // When upload button is clicked
        $(document).on('click', '#spp_upload_button', function(e) {
            e.preventDefault();
            
            // If the media uploader already exists, open it
            if (mediaUploader) {
                mediaUploader.open();
                return;
            }
            
            // Create the media uploader
            mediaUploader = wp.media({
                title: sppData.title,
                button: {
                    text: sppData.button
                },
                multiple: false // Only allow one image to be selected
            });
            
            // When an image is selected
            mediaUploader.on('select', function() {
                var attachment = mediaUploader.state().get('selection').first().toJSON();
                
                // Set the hidden input value to the attachment ID
                $('#spp_profile_picture_id').val(attachment.id);
                
                // Update the preview image
                $('.spp-preview').html('<img src="' + attachment.url + '" alt="">');
                
                // Show the remove button if it's not already visible
                if ($('#spp_remove_button').length === 0) {
                    $('.spp-upload-button').after(' <button type="button" class="button spp-remove-button" id="spp_remove_button">Remove Image</button>');
                }
            });
            
            // Open the uploader
            mediaUploader.open();
        });
        
        // When remove button is clicked (using event delegation)
        $(document).on('click', '#spp_remove_button', function(e) {
            e.preventDefault();
            
            // Clear the hidden input
            $('#spp_profile_picture_id').val('');
            
            var userId = $('#user_id').val() || $('#user_login').closest('form').find('input[name="user_id"]').val() || 0;
            
            // Replace the preview with the default avatar
            $.ajax({
                url: ajaxurl,
                type: 'POST',
                data: {
                    action: 'spp_get_default_avatar',
                    user_id: userId,
                    security: sppData.security
                },
                success: function(response) {
                    if (response.success) {
                        $('.spp-preview').html(response.data);
                    }
                }
            });
            
            // Remove the remove button
            $(this).remove();
        });
    });
})(jQuery);
